@@ -22,41 +22,38 @@
 
 #include "filteractionwithstringlist.h"
 
-namespace PimCommon
-{
+namespace PimCommon {
 class MinimumComboBox;
 }
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 //=============================================================================
 // FilterActionAddTag - append tag to message
 // Appends a tag to messages
 //=============================================================================
-class FilterActionAddTag: public FilterAction
+class FilterActionAddTag : public FilterAction
 {
     Q_OBJECT
 public:
     explicit FilterActionAddTag(QObject *parent = nullptr);
-    ReturnCode process(ItemContext &context, bool applyOnOutbound) const Q_DECL_OVERRIDE;
-    SearchRule::RequiredPart requiredPart() const Q_DECL_OVERRIDE;
+    ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    SearchRule::RequiredPart requiredPart() const override;
 
     static FilterAction *newAction();
 
-    bool isEmpty() const Q_DECL_OVERRIDE;
+    bool isEmpty() const override;
 
-    void argsFromString(const QString &argsStr) Q_DECL_OVERRIDE;
-    QString argsAsString() const Q_DECL_OVERRIDE;
-    QString displayString() const Q_DECL_OVERRIDE;
-    bool argsFromStringInteractive(const QString &argsStr, const QString &filterName) Q_DECL_OVERRIDE;
+    void argsFromString(const QString &argsStr) override;
+    QString argsAsString() const override;
+    QString displayString() const override;
+    bool argsFromStringInteractive(const QString &argsStr, const QString &filterName) override;
 
-    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
-    void applyParamWidgetValue(QWidget *paramWidget) Q_DECL_OVERRIDE;
-    void setParamWidgetValue(QWidget *paramWidget) const Q_DECL_OVERRIDE;
-    void clearParamWidget(QWidget *paramWidget) const Q_DECL_OVERRIDE;
+    QWidget *createParamWidget(QWidget *parent) const override;
+    void applyParamWidgetValue(QWidget *paramWidget) override;
+    void setParamWidgetValue(QWidget *paramWidget) const override;
+    void clearParamWidget(QWidget *paramWidget) const override;
 
-    QString informationAboutNotValidAction() const Q_DECL_OVERRIDE;
+    QString informationAboutNotValidAction() const override;
 private Q_SLOTS:
     void slotTagListingFinished();
 
@@ -67,7 +64,6 @@ private:
     QString mParameter;
     mutable PimCommon::MinimumComboBox *mComboBox;
 };
-
 }
 
 #endif
