@@ -82,12 +82,11 @@ using namespace MailCommon;
 //
 //=============================================================================
 
-KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollection,
-                               QWidget *parent, bool createDummyFilter)
-    : QDialog(parent),
-      mFilter(nullptr),
-      mDoNotClose(false),
-      mIgnoreFilterUpdates(true)
+KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollection, QWidget *parent, bool createDummyFilter)
+    : QDialog(parent)
+    , mFilter(nullptr)
+    , mDoNotClose(false)
+    , mIgnoreFilterUpdates(true)
 {
     setWindowTitle(i18n("Filter Rules"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -109,9 +108,9 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
     okButton->setFocus();
     KWindowSystem::setIcons(winId(),
                             qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),
-                                    IconSize(KIconLoader::Desktop)),
+                                                      IconSize(KIconLoader::Desktop)),
                             qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),
-                                    IconSize(KIconLoader::Small)));
+                                                      IconSize(KIconLoader::Small)));
     user1Button->setText(i18n("Import..."));
     user2Button->setText(i18n("Export..."));
     user3Button->setText(i18n("Convert to..."));
@@ -151,7 +150,7 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
 
     connect(menu, &QMenu::triggered, this, &KMFilterDialog::slotImportFilter);
 
-    act = new QAction(i18n("GMail filters"), this);
+    act = new QAction(i18n("Gmail filters"), this);
     act->setData(QVariant::fromValue(MailCommon::FilterImporterExporter::GmailFilter));
     menu->addAction(act);
 
@@ -200,8 +199,8 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
 
     QGroupBox *patternGroupBox = new QGroupBox(i18n("Filter Criteria"), page1);
     QHBoxLayout *layout = new QHBoxLayout(patternGroupBox);
-    mPatternEdit =
-        new MailCommon::SearchPatternEdit(
+    mPatternEdit
+        = new MailCommon::SearchPatternEdit(
         patternGroupBox, MailCommon::SearchPatternEdit::MatchAllMessages);
     layout->addWidget(mPatternEdit);
 
@@ -230,13 +229,13 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
         bg->addButton(mApplyOnForAll);
         vbl3->addWidget(mApplyOnForAll);
 
-        mApplyOnForTraditional =
-            new QRadioButton(i18n("from all but online IMAP accounts"), mAdvOptsGroup);
+        mApplyOnForTraditional
+            = new QRadioButton(i18n("from all but online IMAP accounts"), mAdvOptsGroup);
         bg->addButton(mApplyOnForTraditional);
         vbl3->addWidget(mApplyOnForTraditional);
 
-        mApplyOnForChecked =
-            new QRadioButton(i18n("from checked accounts only"), mAdvOptsGroup);
+        mApplyOnForChecked
+            = new QRadioButton(i18n("from checked accounts only"), mAdvOptsGroup);
         bg->addButton(mApplyOnForChecked);
         vbl3->addWidget(mApplyOnForChecked);
         vbl3->addStretch(2);
@@ -244,8 +243,8 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
         mAccountList = new KMFilterAccountList(mAdvOptsGroup);
         gl->addWidget(mAccountList, 0, 1, 4, 3);
 
-        mApplyOnOut =
-            new QCheckBox(i18n("Apply this filter to &sent messages"), mAdvOptsGroup);
+        mApplyOnOut
+            = new QCheckBox(i18n("Apply this filter to &sent messages"), mAdvOptsGroup);
         mApplyOnOut->setToolTip(
             i18n("<p>The filter will be triggered <b>after</b> the message is sent "
                  "and it will only affect the local copy of the message.</p>"
@@ -253,24 +252,24 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
                  "please use \"Apply this filter <b>before</b> sending messages\".</p>"));
         gl->addWidget(mApplyOnOut, 4, 0, 1, 4);
 
-        mApplyBeforeOut =
-            new QCheckBox(i18n("Apply this filter &before sending messages"), mAdvOptsGroup);
+        mApplyBeforeOut
+            = new QCheckBox(i18n("Apply this filter &before sending messages"), mAdvOptsGroup);
         mApplyBeforeOut->setToolTip(
             i18n("<p>The filter will be triggered <b>before</b> the message is sent "
                  "and it will affect both the local copy and the sent copy of the message.</p>"
                  "<p>This is required if the recipient's copy also needs to be modified.</p>"));
         gl->addWidget(mApplyBeforeOut, 5, 0, 1, 4);
 
-        mApplyOnCtrlJ =
-            new QCheckBox(i18n("Apply this filter on manual &filtering"), mAdvOptsGroup);
+        mApplyOnCtrlJ
+            = new QCheckBox(i18n("Apply this filter on manual &filtering"), mAdvOptsGroup);
         gl->addWidget(mApplyOnCtrlJ, 6, 0, 1, 4);
 
-        mStopProcessingHere =
-            new QCheckBox(i18n("If this filter &matches, stop processing here"), mAdvOptsGroup);
+        mStopProcessingHere
+            = new QCheckBox(i18n("If this filter &matches, stop processing here"), mAdvOptsGroup);
         gl->addWidget(mStopProcessingHere, 7, 0, 1, 4);
 
-        mConfigureShortcut =
-            new QCheckBox(i18n("Add this filter to the Apply Filter menu"), mAdvOptsGroup);
+        mConfigureShortcut
+            = new QCheckBox(i18n("Add this filter to the Apply Filter menu"), mAdvOptsGroup);
         gl->addWidget(mConfigureShortcut, 8, 0, 1, 2);
 
         QLabel *keyButtonLabel = new QLabel(i18n("Shortcut:"), mAdvOptsGroup);
@@ -284,8 +283,8 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
         mKeySeqWidget->setModifierlessAllowed(true);
         mKeySeqWidget->setCheckActionCollections(actionCollection);
 
-        mConfigureToolbar =
-            new QCheckBox(i18n("Additionally add this filter to the toolbar"), mAdvOptsGroup);
+        mConfigureToolbar
+            = new QCheckBox(i18n("Additionally add this filter to the toolbar"), mAdvOptsGroup);
         gl->addWidget(mConfigureToolbar, 9, 0, 1, 4);
         mConfigureToolbar->setEnabled(false);
 
@@ -383,7 +382,7 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
             this, &KMFilterDialog::slotDialogUpdated);
     connect(mFilterList, &KMFilterListBox::filterOrderAltered, this, &KMFilterDialog::slotDialogUpdated);
     connect(mPatternEdit, &MailCommon::SearchPatternEdit::patternChanged, this, &KMFilterDialog::slotDialogUpdated);
-    connect(mActionLister, SIGNAL(widgetAdded(QWidget*)), this, SLOT(slotDialogUpdated()));
+    connect(mActionLister, SIGNAL(widgetAdded(QWidget *)), this, SLOT(slotDialogUpdated()));
     connect(mActionLister, SIGNAL(widgetRemoved()), this, SLOT(slotDialogUpdated()));
     connect(mActionLister, &MailCommon::FilterActionWidgetLister::filterModified, this, &KMFilterDialog::slotDialogUpdated);
     connect(mActionLister, &MailCommon::FilterActionWidgetLister::clearWidgets, this, &KMFilterDialog::slotDialogUpdated);
@@ -624,7 +623,6 @@ void KMFilterDialog::slotApplicableAccountsChanged()
 {
     // Advanced tab functionality - Update list of accounts this filter applies to
     if (mFilter && mApplyOnForChecked->isEnabled() && mApplyOnForChecked->isChecked()) {
-
         QTreeWidgetItemIterator it(mAccountList);
 
         while (QTreeWidgetItem *item = *it) {
@@ -784,4 +782,3 @@ void KMFilterDialog::slotHelp()
 {
     PimCommon::Util::invokeHelp(QStringLiteral("kmail2/filters.html"));
 }
-
