@@ -37,9 +37,7 @@
 
 class KJob;
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 class ExpireJob : public ScheduledJob
 {
     Q_OBJECT
@@ -47,8 +45,8 @@ public:
     explicit ExpireJob(const Akonadi::Collection &folder, bool immediate);
     virtual ~ExpireJob();
 
-    void execute() Q_DECL_OVERRIDE;
-    void kill() Q_DECL_OVERRIDE;
+    void execute() override;
+    void kill() override;
 
 private:
     void slotDoWork();
@@ -79,17 +77,16 @@ public:
     {
     }
 
-    ScheduledJob *run() Q_DECL_OVERRIDE {
+    ScheduledJob *run() override
+    {
         return folder().isValid() ? new ExpireJob(folder(), isImmediate()) : 0;
     }
 
-    int taskTypeId() const Q_DECL_OVERRIDE
+    int taskTypeId() const override
     {
         return 1;
     }
 };
-
 } // namespace
 
 #endif
-
