@@ -28,8 +28,7 @@
  * The string can be either a message header, or a pseudo header, such
  * as \<body\>
  */
-namespace MailCommon
-{
+namespace MailCommon {
 class SearchRuleString : public SearchRule
 {
 public:
@@ -40,9 +39,7 @@ public:
      * @param function The function to use for searching.
      * @param contents The contents to search for.
      */
-    explicit SearchRuleString(const QByteArray &field = QByteArray(),
-                              Function function = FuncContains,
-                              const QString &contents = QString());
+    explicit SearchRuleString(const QByteArray &field = QByteArray(), Function function = FuncContains, const QString &contents = QString());
 
     /**
      * Creates a new string search rule from an @p other rule.
@@ -62,17 +59,17 @@ public:
     /**
      * @copydoc SearchRule::isEmpty()
      */
-    bool isEmpty() const Q_DECL_OVERRIDE;
+    bool isEmpty() const override;
 
     /**
      * @copydoc SearchRule::requiredPart()
      */
-    RequiredPart requiredPart() const Q_DECL_OVERRIDE;
+    RequiredPart requiredPart() const override;
 
     /**
      * @copydoc SearchRule::matches()
      */
-    bool matches(const Akonadi::Item &item) const Q_DECL_OVERRIDE;
+    bool matches(const Akonadi::Item &item) const override;
 
     /**
      * A helper method for the main matches() method.
@@ -83,8 +80,8 @@ public:
     /**
      * @copydoc SearchRule::addQueryTerms()
      */
-    void addQueryTerms(Akonadi::SearchTerm &groupTerm, bool &emptyIsNotAnError) const Q_DECL_OVERRIDE;
-    QString informationAboutNotValidRules() const Q_DECL_OVERRIDE;
+    void addQueryTerms(Akonadi::SearchTerm &groupTerm, bool &emptyIsNotAnError) const override;
+    QString informationAboutNotValidRules() const override;
 };
 }
 #endif // SEARCHRULESTRING_H
